@@ -34,10 +34,10 @@ class TimeperiodRange extends Model
     public function getColumnDefinitions()
     {
         return [
-            'timeperiod_id'     => t('Timeperiod Range Period Id'),
-            'range_key'         => t('Timeperiod Range Key'),
-            'environment_id'    => t('Timeperiod Range Environment Id'),
-            'range_value'       => t('Timeperiod Range Value')
+            'timeperiod_id'     => t('Timeperiod Id'),
+            'range_key'         => t('Timeperiod Range Date(s)/Day'),
+            'environment_id'    => t('Environment Id'),
+            'range_value'       => t('Timeperiod Range Time')
         ];
     }
 
