@@ -12,6 +12,7 @@ use Icinga\Module\Icingadb\Common\Database;
 use Icinga\Module\Icingadb\Common\HostLink;
 use Icinga\Module\Icingadb\Common\HostStates;
 use Icinga\Module\Icingadb\Common\Links;
+use Icinga\Module\Icingadb\Common\TicketLinks;
 use Icinga\Module\Icingadb\Hook\ExtensionHook\ObjectDetailExtensionHook;
 use Icinga\Module\Icingadb\Widget\MarkdownText;
 use Icinga\Module\Icingadb\Common\ServiceLink;
@@ -47,6 +48,7 @@ class EventDetail extends BaseHtmlElement
     use Database;
     use HostLink;
     use ServiceLink;
+    use TicketLinks;
 
     protected $tag = 'div';
 
@@ -62,23 +64,34 @@ class EventDetail extends BaseHtmlElement
 
     protected function assembleNotificationEvent(NotificationHistory $notification)
     {
-        $pluginOutput = [
-            HtmlElement::create('h2', null, $notification->author ? t('Comment') : t('Plugin Output')),
-            HtmlElement::create('div', [
-                'id'    => 'check-output-' . (
-                    $notification->object_type === 'host'
-                        ? $this->event->host->checkcommand_name
-                        : $this->event->service->checkcommand_name
-                ),
-                'class' => 'collapsible',
-                'data-visible-height' => 100
-            ], new PluginOutputContainer(
-                (new PluginOutput($notification->text))
-                    ->setCommandName($notification->object_type === 'host'
-                        ? $this->event->host->checkcommand_name
-                        : $this->event->service->checkcommand_name)
-            ))
-        ];
+        $pluginOutput = [];
+
+        $commandName = $notification->object_type === 'host'
+            ? $this->event->host->checkcommand_name
+            : $this->event->service->checkcommand_name;
+        if (isset($commandName)) {
+            if (empty($notification->text)) {
+                $notificationText = new EmptyState(t('Output unavailable.'));
+            } else {
+                $notificationText = new PluginOutputContainer(
+                    (new PluginOutput($notification->text))
+                        ->setCommandName($notification->object_type === 'host'
+                            ? $this->event->host->checkcommand_name
+                            : $this->event->service->checkcommand_name)
+                );
+            }
+
+            $pluginOutput = [
+                HtmlElement::create('h2', null, $notification->author ? t('Comment') : t('Plugin Output')),
+                HtmlElement::create('div', [
+                    'id'    => 'check-output-' . $commandName,
+                    'class' => 'collapsible',
+                    'data-visible-height' => 100
+                ], $notificationText)
+            ];
+        } else {
+            $pluginOutput[] = new EmptyState(t('Waiting for Icinga DB to synchronize the config.'));
+        }
 
         if ($notification->object_type === 'host') {
             $objectKey = t('Host');
@@ -160,23 +173,32 @@ class EventDetail extends BaseHtmlElement
 
     protected function assembleStateChangeEvent(StateHistory $stateChange)
     {
-        $pluginOutput = [
-            new HtmlElement('h2', null, Text::create(t('Plugin Output'))),
-            HtmlElement::create('div', [
-                'id'    => 'check-output-' . (
-                    $stateChange->object_type === 'host'
-                        ? $this->event->host->checkcommand_name
-                        : $this->event->service->checkcommand_name
-                ),
-                'class' => 'collapsible',
-                'data-visible-height' => 100
-            ], new PluginOutputContainer(
-                (new PluginOutput($stateChange->output . "\n" . $stateChange->long_output))
-                    ->setCommandName($stateChange->object_type === 'host'
-                        ? $this->event->host->checkcommand_name
-                        : $this->event->service->checkcommand_name)
-            ))
-        ];
+        $pluginOutput = [];
+
+        $commandName = $stateChange->object_type === 'host'
+            ? $this->event->host->checkcommand_name
+            : $this->event->service->checkcommand_name;
+        if (isset($commandName)) {
+            if (empty($stateChange->output) && empty($stateChange->long_output)) {
+                $commandOutput = new EmptyState(t('Output unavailable.'));
+            } else {
+                $commandOutput = new PluginOutputContainer(
+                    (new PluginOutput($stateChange->output . "\n" . $stateChange->long_output))
+                        ->setCommandName($commandName)
+                );
+            }
+
+            $pluginOutput = [
+                new HtmlElement('h2', null, Text::create(t('Plugin Output'))),
+                HtmlElement::create('div', [
+                    'id'    => 'check-output-' . $commandName,
+                    'class' => 'collapsible',
+                    'data-visible-height' => 100
+                ], $commandOutput)
+            ];
+        } else {
+            $pluginOutput[] = new EmptyState(t('Waiting for Icinga DB to synchronize the config.'));
+        }
 
         if ($stateChange->object_type === 'host') {
             $objectKey = t('Host');
@@ -245,7 +267,7 @@ class EventDetail extends BaseHtmlElement
     {
         $commentInfo = [
             new HtmlElement('h2', null, Text::create(t('Comment'))),
-            new MarkdownText($downtime->comment)
+            new MarkdownText($this->createTicketLinks($downtime->comment))
         ];
 
         $eventInfo = [new HtmlElement('h2', null, Text::create(t('Event Info')))];
@@ -344,7 +366,7 @@ class EventDetail extends BaseHtmlElement
     {
         $commentInfo = [
             new HtmlElement('h2', null, Text::create(t('Comment'))),
-            new MarkdownText($comment->comment)
+            new MarkdownText($this->createTicketLinks($comment->comment))
         ];
 
         $eventInfo = [new HtmlElement('h2', null, Text::create(t('Event Info')))];
@@ -456,14 +478,18 @@ class EventDetail extends BaseHtmlElement
         if ($acknowledgement->comment) {
             $commentInfo = [
                 new HtmlElement('h2', null, Text::create(t('Comment'))),
-                new MarkdownText($acknowledgement->comment)
+                new MarkdownText($this->createTicketLinks($acknowledgement->comment))
             ];
+        } elseif (! isset($acknowledgement->author)) {
+            $commentInfo[] = new EmptyState(t('This acknowledgement was set before Icinga DB history recording'));
         }
 
         $eventInfo = [
             new HtmlElement('h2', null, Text::create(t('Event Info'))),
             new HorizontalKeyValue(t('Set on'), DateFormatter::formatDateTime($acknowledgement->set_time)),
-            new HorizontalKeyValue(t('Author'), [new Icon('user'), $acknowledgement->author]),
+            new HorizontalKeyValue(t('Author'), $acknowledgement->author
+                ? [new Icon('user'), $acknowledgement->author]
+                : new EmptyState(t('n. a.'))),
             $acknowledgement->object_type === 'host'
                 ? new HorizontalKeyValue(t('Host'), HtmlElement::create(
                     'span',
@@ -488,11 +514,12 @@ class EventDetail extends BaseHtmlElement
                 ? DateFormatter::formatDateTime($acknowledgement->expire_time)
                 : new EmptyState(t('Never'))
             );
-            $eventInfo[] = new HorizontalKeyValue(t('Sticky'), $acknowledgement->is_sticky ? t('Yes') : t('No'));
-            $eventInfo[] = new HorizontalKeyValue(
-                t('Persistent'),
-                $acknowledgement->is_persistent ? t('Yes') : t('No')
-            );
+            $eventInfo[] = new HorizontalKeyValue(t('Sticky'), isset($acknowledgement->is_sticky)
+                ? ($acknowledgement->is_sticky ? t('Yes') : t('No'))
+                : new EmptyState(t('n. a.')));
+            $eventInfo[] = new HorizontalKeyValue(t('Persistent'), isset($acknowledgement->is_persistent)
+                ? ($acknowledgement->is_persistent ? t('Yes') : t('No'))
+                : new EmptyState(t('n. a.')));
         } else {
             $eventInfo[] = new HorizontalKeyValue(
                 t('Cleared on'),
@@ -506,7 +533,7 @@ class EventDetail extends BaseHtmlElement
             } else {
                 $expired = false;
                 if ($acknowledgement->expire_time) {
-                    $now = (new DateTime())->setTimezone(new DateTimeZone(DateTimeZone::UTC));
+                    $now = (new DateTime())->setTimezone(new DateTimeZone('UTC'));
                     $expiresOn = clone $now;
                     $expiresOn->setTimestamp($acknowledgement->expire_time);
                     if ($now <= $expiresOn) {
