@@ -6,6 +6,7 @@ namespace Icinga\Module\Icingadb\Widget\Detail;
 
 use Exception;
 use Icinga\Application\ClassLoader;
+use Icinga\Application\Hook;
 use Icinga\Application\Hook\GrapherHook;
 use Icinga\Application\Icinga;
 use Icinga\Application\Logger;
@@ -38,7 +39,6 @@ use Icinga\Module\Icingadb\Widget\PluginOutputContainer;
 use Icinga\Module\Icingadb\Widget\ShowMore;
 use Icinga\Module\Icingadb\Widget\TagList;
 use Icinga\Module\Monitoring\Hook\DetailviewExtensionHook;
-use Icinga\Web\Hook;
 use Icinga\Web\Navigation\Navigation;
 use ipl\Html\Attributes;
 use ipl\Html\BaseHtmlElement;
@@ -74,10 +74,18 @@ class ObjectDetail extends BaseHtmlElement
     public function __construct($object)
     {
         $this->object = $object;
-        $this->compatObject = CompatHost::fromModel($object);
         $this->objectType = $object instanceof Host ? 'host' : 'service';
     }
 
+    protected function compatObject()
+    {
+        if ($this->compatObject === null) {
+            $this->compatObject = CompatHost::fromModel($this->object);
+        }
+
+        return $this->compatObject;
+    }
+
     protected function createPrintHeader()
     {
         $info = [new HorizontalKeyValue(t('Name'), $this->object->name)];
@@ -123,7 +131,7 @@ class ObjectDetail extends BaseHtmlElement
             $item->setObject($this->object);
         }
 
-        foreach ($this->object->action_url->action_url ?? [] as $url) {
+        foreach ($this->object->action_url->first()->action_url ?? [] as $url) {
             $url = $this->expandMacros($url, $this->object);
             $navigation->addItem(
                 Html::wantHtml([
@@ -151,14 +159,16 @@ class ObjectDetail extends BaseHtmlElement
             }
         }
 
-        foreach (Hook::all('Monitoring\\' . ucfirst($this->objectType) . 'Actions') as $hook) {
-            $moduleName = ClassLoader::extractModuleName(get_class($hook));
-            if (! isset($nativeExtensionProviders[$moduleName])) {
-                try {
-                    $navigation->merge($hook->getNavigation($this->compatObject));
-                } catch (Exception $e) {
-                    Logger::error("Failed to load legacy action hook: %s\n%s", $e, $e->getTraceAsString());
-                    $navigation->addItem($moduleName, ['label' => IcingaException::describe($e), 'url' => '#']);
+        if (Icinga::app()->getModuleManager()->hasInstalled('monitoring')) {
+            foreach (Hook::all('Monitoring\\' . ucfirst($this->objectType) . 'Actions') as $hook) {
+                $moduleName = ClassLoader::extractModuleName(get_class($hook));
+                if (! isset($nativeExtensionProviders[$moduleName])) {
+                    try {
+                        $navigation->merge($hook->getNavigation($this->compatObject()));
+                    } catch (Exception $e) {
+                        Logger::error("Failed to load legacy action hook: %s\n%s", $e, $e->getTraceAsString());
+                        $navigation->addItem($moduleName, ['label' => IcingaException::describe($e), 'url' => '#']);
+                    }
                 }
             }
         }
@@ -169,7 +179,7 @@ class ObjectDetail extends BaseHtmlElement
 
         return [
             Html::tag('h2', t('Actions')),
-            new HtmlString($navigation->getRenderer()->setCssClass('actions')->render()),
+            new HtmlString($navigation->getRenderer()->setCssClass('object-detail-actions')->render()),
             $moduleActions->isEmpty() ? null : $moduleActions
         ];
     }
@@ -205,7 +215,7 @@ class ObjectDetail extends BaseHtmlElement
         $content = [Html::tag('h2', t('Comments'))];
 
         if ($comments->hasResult()) {
-            $content[] = (new CommentList($comments))->setObjectLinkDisabled();
+            $content[] = (new CommentList($comments))->setObjectLinkDisabled()->setTicketLinkEnabled();
             $content[] = (new ShowMore($comments, $link))->setBaseTarget('_next');
         } else {
             $content[] = new EmptyState(t('No comments created.'));
@@ -256,7 +266,7 @@ class ObjectDetail extends BaseHtmlElement
         $content = [Html::tag('h2', t('Downtimes'))];
 
         if ($downtimes->hasResult()) {
-            $content[] = (new DowntimeList($downtimes))->setObjectLinkDisabled();
+            $content[] = (new DowntimeList($downtimes))->setObjectLinkDisabled()->setTicketLinkEnabled();
             $content[] = (new ShowMore($downtimes, $link))->setBaseTarget('_next');
         } else {
             $content[] = new EmptyState(t('No downtimes scheduled.'));
@@ -309,7 +319,7 @@ class ObjectDetail extends BaseHtmlElement
         $navigation = new Navigation();
         $notes = trim($this->object->notes);
 
-        foreach ($this->object->notes_url->notes_url ?? [] as $url) {
+        foreach ($this->object->notes_url->first()->notes_url ?? [] as $url) {
             $url = $this->expandMacros($url, $this->object);
             $navigation->addItem(
                 Html::wantHtml([
@@ -331,7 +341,7 @@ class ObjectDetail extends BaseHtmlElement
         $content = [];
 
         if (! $navigation->isEmpty() && $navigation->hasRenderableItems()) {
-            $content[] = new HtmlString($navigation->getRenderer()->setCssClass('actions')->render());
+            $content[] = new HtmlString($navigation->getRenderer()->setCssClass('object-detail-actions')->render());
         }
 
         if ($notes !== '') {
@@ -430,11 +440,15 @@ class ObjectDetail extends BaseHtmlElement
 
         $nativeExtensionProviders = [];
         foreach ($extensions as $extension) {
-            if ($extension->getAttributes()->has('data-icinga-module')) {
+            if ($extension instanceof BaseHtmlElement && $extension->getAttributes()->has('data-icinga-module')) {
                 $nativeExtensionProviders[$extension->getAttributes()->get('data-icinga-module')->getValue()] = true;
             }
         }
 
+        if (! Icinga::app()->getModuleManager()->hasInstalled('monitoring')) {
+            return $extensions;
+        }
+
         foreach (Hook::all('Grapher') as $grapher) {
             /** @var GrapherHook $grapher */
             $moduleName = ClassLoader::extractModuleName(get_class($grapher));
@@ -444,7 +458,7 @@ class ObjectDetail extends BaseHtmlElement
             }
 
             try {
-                $graph = HtmlString::create($grapher->getPreviewHtml($this->compatObject));
+                $graph = HtmlString::create($grapher->getPreviewHtml($this->compatObject()));
             } catch (Exception $e) {
                 Logger::error("Failed to load legacy grapher: %s\n%s", $e, $e->getTraceAsString());
                 $graph = Text::create(IcingaException::describe($e));
@@ -469,7 +483,7 @@ class ObjectDetail extends BaseHtmlElement
             try {
                 $renderedExtension = $extension
                     ->setView(Icinga::app()->getViewRenderer()->view)
-                    ->getHtmlForObject($this->compatObject);
+                    ->getHtmlForObject($this->compatObject());
 
                 $extensionHtml = new HtmlElement(
                     'div',
